"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var graphql_1 = require("graphql");
var utils_1 = require("./utils");
function convertSDL(sdl, commonjs) {
    if (commonjs === void 0) { commonjs = false; }
    return new SDLConverter(commonjs, sdl).print();
}
exports.convertSDL = convertSDL;
/**
 * Convert an existing SDL schema into a Nexus GraphQL format
 */
var SDLConverter = /** @class */ (function () {
    function SDLConverter(commonjs, sdl) {
        if (commonjs === void 0) { commonjs = false; }
        this.export = commonjs ? "exports." : "export const ";
        this.schema = graphql_1.buildSchema(sdl);
        this.groupedTypes = utils_1.groupTypes(this.schema);
    }
    SDLConverter.prototype.print = function () {
        return [
            this.printObjectTypes(),
            this.printInterfaceTypes(),
            this.printInputObjectTypes(),
            this.printUnionTypes(),
            this.printEnumTypes(),
            this.printScalarTypes(),
        ].join("\n\n");
    };
    SDLConverter.prototype.printObjectTypes = function () {
        var _this = this;
        if (this.groupedTypes.object.length > 0) {
            return this.groupedTypes.object
                .map(function (t) { return _this.printObjectType(t); })
                .join("\n");
        }
        return "";
    };
    SDLConverter.prototype.printObjectType = function (type) {
        return this.printBlock([
            "" + this.export + type.name + " = objectType({",
            "  name: \"" + type.name + "\"",
            "})",
        ]);
        // if (type.getInterfaces().length > 0) {
        //   const interfaceNames = type
        //     .getInterfaces()
        //     .map((i) => JSON.stringify(i.name))
        //     .join(", ");
        //   str.push(`  t.implements(${interfaceNames})`);
        // }
        // Object.keys(type.getFields()).forEach((fieldName) => {
        //   if (isInterfaceField(type, fieldName)) {
        //     return;
        //   }
        //   eachObj(type.getFields(), (field, key) => {
        //     getFieldType(field);
        //   });
        // });
        // return str.join("\n");
    };
    SDLConverter.prototype.printInterfaceTypes = function () {
        var _this = this;
        if (this.groupedTypes.interface.length) {
            return this.groupedTypes.interface
                .map(function (t) { return _this.printInterfaceType(t); })
                .join("\n");
        }
        return "";
    };
    SDLConverter.prototype.printInterfaceType = function (type) {
        return this.printBlock([
            "" + this.export + type.name + " = interfaceType({",
            "  name: \"" + type.name + "\",",
            this.maybeDescription(type),
            "  definition(t) {",
            "  }",
            "});",
        ]);
        // eachObj(type.getFields(), (field, key) => {
        //   getFieldType(field);
        // });
        // return str.join("\n");
    };
    SDLConverter.prototype.printEnumTypes = function () {
        var _this = this;
        if (this.groupedTypes.enum.length) {
            return this.groupedTypes.enum
                .map(function (t) { return _this.printEnumType(t); })
                .join("\n");
        }
        return "";
    };
    SDLConverter.prototype.printEnumType = function (type) {
        return this.printBlock([
            "" + this.export + type.name + " = enumType({",
            "  name: \"" + type.name + "\",",
            this.maybeDescription(type),
            "  definition(t) {",
            "  }",
            "});",
        ]);
    };
    SDLConverter.prototype.printInputObjectTypes = function () {
        var _this = this;
        if (this.groupedTypes.input.length) {
            return this.groupedTypes.input.map(function (t) { return _this.printInputObjectType(t); });
        }
        return "";
    };
    SDLConverter.prototype.printInputObjectType = function (type) {
        return this.printBlock([
            "" + this.export + type.name + " = inputObjectType({",
            "  name: \"" + type.name + "\",",
            this.maybeDescription(type),
            "  definition(t) {",
            "  }",
            "});",
        ]);
    };
    SDLConverter.prototype.printUnionTypes = function () {
        var _this = this;
        if (this.groupedTypes.union.length) {
            return this.groupedTypes.union
                .map(function (t) { return _this.printUnionType(t); })
                .join("\n");
        }
        return "";
    };
    SDLConverter.prototype.printUnionType = function (type) {
        return this.printBlock([
            "" + this.export + type.name + " = unionType({",
            "  name: \"" + type.name + "\",",
            this.maybeDescription(type),
            "  definition(t) {",
            "  }",
            "});",
        ]);
    };
    SDLConverter.prototype.printScalarTypes = function () {
        var _this = this;
        if (this.groupedTypes.scalar.length) {
            return this.groupedTypes.scalar
                .map(function (t) { return _this.printScalarType(t); })
                .join("\n");
        }
        return "";
    };
    SDLConverter.prototype.printScalarType = function (type) {
        return this.printBlock([
            "" + this.export + type.name + " = scalarType({",
            "  name: " + type.name + "\",",
            this.maybeDescription(type),
            "  definition(t) {",
            "  }",
            "});",
        ]);
    };
    SDLConverter.prototype.maybeDescription = function (type) {
        if (type.description) {
            return "  description: " + JSON.stringify(type.description) + ",";
        }
        return null;
    };
    SDLConverter.prototype.printBlock = function (block) {
        return block.filter(function (t) { return t !== null; }).join("\n");
    };
    return SDLConverter;
}());
exports.SDLConverter = SDLConverter;
var getFieldType = function (type) {
    //
};
var getInputFieldType = function (type) {
    //
};
//# sourceMappingURL=sdlConverter.js.map